Page 37 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 37

Home

    writes:

    I am now in the most embarrassing situation; it robs
    me of all rest, and makes me unfit for every thing. Iam
    in danger of losing at once my honor and my reputation,
    by which I have long had such influence. What think you
    — my sister-in-law is with child... . We have tried every
    method in our power to destroy the childs. . 3

    And what of the accomplishments of this collection of
    "immoral wretches, whore-masters, liars, bankrupts,
    braggarts, and vain fools?" In just a decade, membership
    included about 600 of the most influential men in

    By the activity of our Brethren, the Jesuits have been
    kept out of all the professional chairs at Ingolstadt, and
    our friends prevail.

    The Widow Duchess has set up her academy entirely
    according to our plan, and we have all the Professors in
    the Order.

    last year, for we have procured for them several good
    benefices, parishes, tutorships, &c.

    All the German Schools, and the Benevolent Society,
    are at last under our direction.”

    We have got several zealous members in the courts
    of justice, and we are able to afford them pay, and other
    good additions.

    32

    The Secret Side of History

    In a letter to Marius in September 1783, Weishaupt

    Bavaria. Below are excerpts from a report written in

    Cato's handwriting:

    Our Ghostly Brethren have been very fortunate this